@@ -28,6 +28,7 @@
 
 #include <qplatformdefs.h>
 
+#include <array>
 #include <cmath>
 
 Q_GLOBAL_STATIC(QString, _themeOverride)
@@ -78,8 +79,20 @@ public:
     bool hidden;
     KSharedConfig::Ptr sharedConfig;
 
-    int mDefSize[6];
-    QList<int> mSizes[6];
+    struct GroupInfo {
+        KIconLoader::Group type;
+        const char *name;
+        int defaultSize;
+        QList<int> availableSizes{};
+    };
+    std::array<GroupInfo, KIconLoader::LastGroup> m_iconGroups = {{
+        {KIconLoader::Desktop, "Desktop", 32},
+        {KIconLoader::Toolbar, "Toolbar", 22},
+        {KIconLoader::MainToolbar, "MainToolbar", 22},
+        {KIconLoader::Small, "Small", 16},
+        {KIconLoader::Panel, "Panel", 48},
+        {KIconLoader::Dialog, "Dialog", 32},
+    }};
 
     int mDepth;
     QString mDir, mName, mInternalName, mDesc;
@@ -259,9 +272,9 @@ KIconTheme::KIconTheme(const QString &name, const QString &appName, const QStrin
         && (name == defaultThemeName()
             || name == QLatin1String("hicolor")
             || name == QLatin1String("locolor"))) { /* clang-format on */
-        const QStringList icnlibs = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation);
-        for (QStringList::ConstIterator it = icnlibs.constBegin(), total = icnlibs.constEnd(); it != total; ++it) {
-            const QString cDir = *it + QLatin1Char('/') + appName + QStringLiteral("/icons/") + name + QLatin1Char('/');
+        const QStringList dataDirs = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation);
+        for (const auto &dir : dataDirs) {
+            const QString cDir = dir + QLatin1Char('/') + appName + QLatin1String("/icons/") + name + QLatin1Char('/');
             if (QFileInfo::exists(cDir)) {
                 themeDirs += cDir;
             }
@@ -287,8 +300,8 @@ KIconTheme::KIconTheme(const QString &name, const QString &appName, const QStrin
 
     QString fileName;
     QString mainSection;
-    for (QStringList::ConstIterator it = icnlibs.constBegin(), total = icnlibs.constEnd(); it != total; ++it) {
-        const QString cDir = *it + QLatin1Char('/') + name + QLatin1Char('/');
+    for (const auto &iconDir : std::as_const(icnlibs)) {
+        const QString cDir = iconDir + QLatin1Char('/') + name + QLatin1Char('/');
         if (QDir(cDir).exists()) {
             themeDirs += cDir;
             if (d->mDir.isEmpty()) {
@@ -306,7 +319,7 @@ KIconTheme::KIconTheme(const QString &name, const QString &appName, const QStrin
     }
 
     if (d->mDir.isEmpty()) {
-        qDebug() << "Icon theme" << name << "not found.";
+        qCDebug(KICONTHEMES) << "Icon theme" << name << "not found.";
         return;
     }
 
@@ -320,9 +333,9 @@ KIconTheme::KIconTheme(const QString &name, const QString &appName, const QStrin
     d->mDepth = cfg.readEntry("DisplayDepth", 32);
     d->mInherits = cfg.readEntry("Inherits", QStringList());
     if (name != defaultThemeName()) {
-        for (QStringList::Iterator it = d->mInherits.begin(), total = d->mInherits.end(); it != total; ++it) {
-            if (*it == QLatin1String("default")) {
-                *it = defaultThemeName();
+        for (auto &inheritedTheme : d->mInherits) {
+            if (inheritedTheme == QLatin1String("default")) {
+                inheritedTheme = defaultThemeName();
             }
         }
     }
@@ -335,13 +348,13 @@ KIconTheme::KIconTheme(const QString &name, const QString &appName, const QStrin
         cfg.readEntry("KDE-Extensions", QStringList{QStringLiteral(".png"), QStringLiteral(".svgz"), QStringLiteral(".svg"), QStringLiteral(".xpm")});
 
     const QStringList dirs = cfg.readPathEntry("Directories", QStringList()) + cfg.readPathEntry("ScaledDirectories", QStringList());
-    for (QStringList::ConstIterator it = dirs.begin(); it != dirs.end(); ++it) {
-        KConfigGroup cg(d->sharedConfig, *it);
-        for (QStringList::ConstIterator itDir = themeDirs.constBegin(); itDir != themeDirs.constEnd(); ++itDir) {
-            const QString currentDir(*itDir + *it + QLatin1Char('/'));
+    for (const auto &dirName : dirs) {
+        KConfigGroup cg(d->sharedConfig, dirName);
+        for (const auto &themeDir : std::as_const(themeDirs)) {
+            const QString currentDir(themeDir + dirName + QLatin1Char('/'));
             if (!addedDirs.contains(currentDir) && QDir(currentDir).exists()) {
                 addedDirs.insert(currentDir);
-                KIconThemeDir *dir = new KIconThemeDir(*itDir, *it, cg);
+                KIconThemeDir *dir = new KIconThemeDir(themeDir, dirName, cg);
                 if (dir->isValid()) {
                     if (dir->scale() > 1) {
                         d->mScaledDirs.append(dir);
@@ -355,19 +368,10 @@ KIconTheme::KIconTheme(const QString &name, const QString &appName, const QStrin
         }
     }
 
-    QStringList groups;
-    groups += QStringLiteral("Desktop");
-    groups += QStringLiteral("Toolbar");
-    groups += QStringLiteral("MainToolbar");
-    groups += QStringLiteral("Small");
-    groups += QStringLiteral("Panel");
-    groups += QStringLiteral("Dialog");
-    const int defDefSizes[] = {32, 22, 22, 16, 48, 32};
     KConfigGroup cg(d->sharedConfig, mainSection);
-    for (int i = 0; i < groups.size(); ++i) {
-        const QString group = groups.at(i);
-        d->mDefSize[i] = cg.readEntry(group + QStringLiteral("Default"), defDefSizes[i]);
-        d->mSizes[i] = cg.readEntry(group + QStringLiteral("Sizes"), QList<int>());
+    for (auto &iconGroup : d->m_iconGroups) {
+        iconGroup.defaultSize = cg.readEntry(iconGroup.name + QLatin1String("Default"), iconGroup.defaultSize);
+        iconGroup.availableSizes = cg.readEntry(iconGroup.name + QLatin1String("Sizes"), QList<int>());
     }
 }
 
@@ -429,20 +433,20 @@ int KIconTheme::depth() const
 
 int KIconTheme::defaultSize(KIconLoader::Group group) const
 {
-    if ((group < 0) || (group >= KIconLoader::LastGroup)) {
-        qWarning() << "Illegal icon group: " << group;
+    if (group < 0 || group >= KIconLoader::LastGroup) {
+        qCWarning(KICONTHEMES) << "Invalid icon group:" << group << ", should be one of KIconLoader::Group";
         return -1;
     }
-    return d->mDefSize[group];
+    return d->m_iconGroups[group].defaultSize;
 }
 
 QList<int> KIconTheme::querySizes(KIconLoader::Group group) const
 {
-    if ((group < 0) || (group >= KIconLoader::LastGroup)) {
-        qWarning() << "Illegal icon group: " << group;
+    if (group < 0 || group >= KIconLoader::LastGroup) {
+        qCWarning(KICONTHEMES) << "Invalid icon group:" << group << ", should be one of KIconLoader::Group";
         return QList<int>();
     }
-    return d->mSizes[group];
+    return d->m_iconGroups[group].availableSizes;
 }
 
 QStringList KIconTheme::queryIcons(int size, KIconLoader::Context context) const
@@ -471,29 +475,6 @@ QStringList KIconTheme::queryIcons(int size, KIconLoader::Context context) const
     }
 
     return result;
-
-    /*
-        int delta = 1000, dw;
-
-        // Find close match
-        KIconThemeDir *best = 0L;
-        for(int i=0; i<d->mDirs.size(); ++i) {
-            dir = d->mDirs.at(i);
-            if ((context != KIconLoader::Any) && (context != dir->context())) {
-                continue;
-            }
-            dw = dir->size() - size;
-            if ((dw > 6) || (abs(dw) >= abs(delta)))
-                continue;
-            delta = dw;
-            best = dir;
-        }
-        if (best == 0L) {
-            return QStringList();
-        }
-
-        return best->iconList();
-        */
 }
 
 QStringList KIconTheme::queryIconsByContext(int size, KIconLoader::Context context) const
@@ -632,24 +613,24 @@ QStringList KIconTheme::list()
     // These are not in the icon spec, but e.g. GNOME puts some icons there anyway.
     icnlibs += QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("pixmaps"), QStandardPaths::LocateDirectory);
 
-    for (const QString &it : std::as_const(icnlibs)) {
-        QDir dir(it);
-        const QStringList lst = dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot);
-        for (QStringList::ConstIterator it2 = lst.begin(), total = lst.end(); it2 != total; ++it2) {
-            if ((*it2).startsWith(QLatin1String("default."))) {
+    for (const QString &iconDir : std::as_const(icnlibs)) {
+        QDir dir(iconDir);
+        const QStringList themeDirs = dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot);
+        for (const auto &theme : themeDirs) {
+            if (theme.startsWith(QLatin1String("default."))) {
                 continue;
             }
-            if (!QFileInfo::exists(it + QLatin1Char('/') + *it2 + QLatin1String("/index.desktop"))
-                && !QFileInfo::exists(it + QLatin1Char('/') + *it2 + QLatin1String("/index.theme"))) {
+            if (!QFileInfo::exists(iconDir + QLatin1Char('/') + theme + QLatin1String("/index.desktop"))
+                && !QFileInfo::exists(iconDir + QLatin1Char('/') + theme + QLatin1String("/index.theme"))) {
                 continue;
             }
-            KIconTheme oink(*it2);
+            KIconTheme oink(theme);
             if (!oink.isValid()) {
                 continue;
             }
 
-            if (!_theme_list()->contains(*it2)) {
-                _theme_list()->append(*it2);
+            if (!_theme_list()->contains(theme)) {
+                _theme_list()->append(theme);
             }
         }
     }
